#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-HW0bPQQ2gvn8bx9aD1Hful
key:                  crypto-pubkey-types-0.4.3-HW0bPQQ2gvn8bx9aD1Hful
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  f2c8547c11605a4cf13d419da8fdca39
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypto-pubkey-types-0.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-pubkey-types
hs-libraries:         HScrypto-pubkey-types-0.4.3-HW0bPQQ2gvn8bx9aD1Hful
depends:
    asn1-encoding-0.9.6-2z60VHsjZ4pGbNwjJKXafj
    asn1-types-0.3.4-3nITPIkdHHLFRev1NfSaGW base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

